// Code generated by 'ccgo wctype/gen.c -crt-import-path  -export-defines  -export-enums  -export-externs X -export-fields F -export-structs  -export-typedefs  -header -hide _OSSwapInt16,_OSSwapInt32,_OSSwapInt64 -ignore-unsupported-alignment -o wctype/wctype_freebsd_arm.go -pkgname wctype', DO NOT EDIT.

package wctype

var CAPI = map[string]struct{}{
	"__istype_l":     {},
	"__maskrune_l":   {},
	"__wcwidth_l":    {},
	"iswalnum_l":     {},
	"iswalpha_l":     {},
	"iswblank_l":     {},
	"iswcntrl_l":     {},
	"iswdigit_l":     {},
	"iswgraph_l":     {},
	"iswhexnumber_l": {},
	"iswideogram_l":  {},
	"iswlower_l":     {},
	"iswnumber_l":    {},
	"iswphonogram_l": {},
	"iswprint_l":     {},
	"iswpunct_l":     {},
	"iswrune_l":      {},
	"iswspace_l":     {},
	"iswspecial_l":   {},
	"iswupper_l":     {},
	"iswxdigit_l":    {},
	"towlower_l":     {},
	"towupper_l":     {},
}
