/*
Copyright 2023 The OpenVEX Authors
SPDX-License-Identifier: Apache-2.0
*/

// Package csaf provides a library for Common Security Advisory Framework Version 2.0 (CSAF) documents.
//
// https://docs.oasis-open.org/csaf/csaf/v2.0/os/csaf-v2.0-os.html
package csaf
