// Code generated by 'ccgo wctype/gen.c -crt-import-path  -export-defines  -export-enums  -export-externs X -export-fields F -export-structs  -export-typedefs  -header -hide _OSSwapInt16,_OSSwapInt32,_OSSwapInt64 -ignore-unsupported-alignment -o wctype/wctype_darwin_amd64.go -pkgname wctype', DO NOT EDIT.

package wctype

var CAPI = map[string]struct{}{
	"__darwin_check_fd_set_overflow": {},
	"__isctype":                      {},
	"__istype":                       {},
	"__wcwidth":                      {},
	"digittoint":                     {},
	"isalnum":                        {},
	"isalpha":                        {},
	"isascii":                        {},
	"isblank":                        {},
	"iscntrl":                        {},
	"isdigit":                        {},
	"isgraph":                        {},
	"ishexnumber":                    {},
	"isideogram":                     {},
	"islower":                        {},
	"isnumber":                       {},
	"isphonogram":                    {},
	"isprint":                        {},
	"ispunct":                        {},
	"isrune":                         {},
	"isspace":                        {},
	"isspecial":                      {},
	"isupper":                        {},
	"iswalnum":                       {},
	"iswalpha":                       {},
	"iswascii":                       {},
	"iswblank":                       {},
	"iswcntrl":                       {},
	"iswctype":                       {},
	"iswdigit":                       {},
	"iswgraph":                       {},
	"iswhexnumber":                   {},
	"iswideogram":                    {},
	"iswlower":                       {},
	"iswnumber":                      {},
	"iswphonogram":                   {},
	"iswprint":                       {},
	"iswpunct":                       {},
	"iswrune":                        {},
	"iswspace":                       {},
	"iswspecial":                     {},
	"iswupper":                       {},
	"iswxdigit":                      {},
	"isxdigit":                       {},
	"toascii":                        {},
	"tolower":                        {},
	"toupper":                        {},
	"towlower":                       {},
	"towupper":                       {},
}
